import React, { useState } from "react";
import ActionButtons from "./ActionButtons";
import CommentForm from "./CommentForm";
import CommentsModal from "./CommentsModal";

const Post = ({ user, time, content, image }) => {
  const [likes, setLikes] = useState(0);
  const [comments, setComments] = useState([]);
  const [newComment, setNewComment] = useState("");
  const [showComments, setShowComments] = useState(false);

  const handleLike = () => setLikes((prev) => prev + 1);

  const handleSubmit = (e) => {
    e.preventDefault();
    if (newComment.trim()) {
      setComments((prev) => [...prev, { text: newComment }]);
      setNewComment("");
    }
  };

  return (
    <div className="mb-6 p-4 bg-white shadow rounded-lg">
      <div className="flex items-center mb-4">
        <div className="w-10 h-10 rounded-full bg-gray-200">
          <img src="/images/logo.webp" alt={`${user}'s Avatar`} />
        </div>
        <div className="ml-3">
          <p className="font-semibold">{user}</p>
          <p className="text-gray-500 text-sm">{time}</p>
        </div>
      </div>
      <p className="text-gray-800 mb-4">{content}</p>
      {image && <img src={image} alt="Post content" className="w-full rounded-lg mb-4" />}
      <div className="flex justify-between mb-4 pb-2 border-b">
        <span>{likes} likes</span>
        <span>{comments.length} comments</span>
      </div>
      <ActionButtons handleLike={handleLike} setShowComments={setShowComments} />
      <CommentForm
        newComment={newComment}
        setNewComment={setNewComment}
        handleSubmit={handleSubmit}
      />
      <CommentsModal
        showComments={showComments}
        setShowComments={setShowComments}
        comments={comments}
      />
    </div>
  );
};

export default Post;
